package org.greenstone.android.tipple.base;

import android.content.Context;
import android.hardware.Camera;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

public class CameraPreview extends SurfaceView implements SurfaceHolder.Callback {

	Camera camera;

	public CameraPreview(Context context) {
		super(context);
		getHolder().addCallback(this);
		getHolder().setType(SurfaceHolder.SURFACE_TYPE_PUSH_BUFFERS);
	}

	@Override
	public void surfaceCreated(SurfaceHolder holder) {
		System.err.println("*** CameraPreview::surfaceCreated()");
		camera = Camera.open();
		try {
			camera.setPreviewDisplay(holder);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Override
	public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
		System.err.println("*** CameraPreview::surfaceChanged()");

		Camera.Parameters parameters = camera.getParameters();
		Camera.Size size = getBestPreviewSize(width, height, parameters);

		if (size != null) {
			parameters.setPreviewSize(size.width, size.height);
			camera.setParameters(parameters);
			camera.startPreview();
		} else {
			System.err.println("Could not find a good camera preview size");
		}
	}

	@Override
	public void surfaceDestroyed(SurfaceHolder holder) {
		System.err.println("*** CameraPreview::surfaceDestroyed()");
		camera.stopPreview();
		camera.release();
		camera = null;
	}

	private Camera.Size getBestPreviewSize(int width, int height, Camera.Parameters parameters) {
		Camera.Size result = null;

		for (Camera.Size size : parameters.getSupportedPreviewSizes()) {
			if (size.width <= width && size.height <= height) {
				if (result == null) {
					result = size;
				} else {
					int resultArea = result.width * result.height;
					int newArea = size.width * size.height;
					if (newArea > resultArea) {
						result = size;
					}
				}
			}
		}

		return (result);
	}
}