package org.mapsforge.android.maps;



import org.mapsforge.core.GeoPoint;

import android.graphics.Point;
import android.graphics.drawable.Drawable;

/**
 * An OverlayMarkerItem holds all parameters of a single element on an {@link ItemizedMarkerOverlay}.
 */
public class OverlayMarkerItem 
{
	/**
	 * Marker used to indicate the item.
	 */
	protected Drawable marker;

	/**
	 * Geographical position of the item.
	 */
	protected final GeoPoint point;

	/**
	 * Title of the item.
	 */
	protected final String title;
	
	/**
	 * Cached position of the item on the map.
	 */
	Point cachedMapPosition;

	/**
	 * Zoom level of the cached map position.
	 */
	byte cachedZoomLevel;

	/**
	 * Constructs a new OverlayItem.
	 * 
	 * @param point
	 *            the geographical position of the item.
	 */
	public OverlayMarkerItem(GeoPoint point, String title) 
	{
		this.point = point;
		this.title = title;
		this.cachedZoomLevel = Byte.MIN_VALUE;
	}

	/**
	 * Returns the marker used to indicate the item (may be null).
	 * 
	 * @return the marker used to indicate the item.
	 */
	public Drawable getMarker() 
	{
		return this.marker;
	}

	/**
	 * Returns the position of the item.
	 * 
	 * @return the position of the item.
	 */
	public GeoPoint getPoint() 
	{
		return this.point;
	}

	/**
	 * Returns the title of the item.
	 * 
	 * @return the title of the item.
	 */
	public String getTitle() 
	{
		return this.title;
	}
	
	/**
	 * Sets the marker that is drawn on the map for this item. If the item marker is null, the
	 * default marker will be drawn instead.
	 * 
	 * @param marker
	 *            the marker that is drawn on the map for this item.
	 */
	public void setMarker(Drawable marker) 
	{
		this.marker = marker;
	}
}





