package org.mapsforge.android.maps;

import org.mapsforge.android.maps.overlay.OverlayItem;
import org.mapsforge.core.GeoPoint;


/**
 * An OverlayTextAudioItem holds all parameters of a single element (capable of displaying text 
 * and/or audio in {@link ItemizedOverlay}.  If the item has not raw audio file, then it will use
 * Text-To-Speech (TTS) to synthesize the audio
 */
public class OverlayTextAudioItem extends OverlayItem
{
	protected final String ttsTitle;
	protected final String ttsSnippet;
	protected final String audioFile;
	
	/**
	 * Constructs a new OverlayTextAduioItem.
	 * 
	 * @param point
	 *            the geographical position of the item.
	 * @param title
	 *            the title of the item.
	 * @param snippet
	 *            the short description of the item.
	 * @param tts_snippet
	 *            optinal phonetically based version of the short description; can be null in
	 *            which case the text in snippet is used.          
	 * @param audio
	 * 			  the audio file to use
	 */
	public OverlayTextAudioItem(GeoPoint point, String title, String ttsTitle, String snippet, String ttsSnippet,
								String audio) 
	{
		super(point,title,snippet);
		this.ttsSnippet = (ttsSnippet != null) ? ttsSnippet : snippet;
		this.ttsTitle = (ttsTitle != null) ? ttsTitle : title;
		this.audioFile = audio;
	}

	/**
	 * Constructs a new OverlayTextAudioItem.
	 * 
	 * @param point
	 *            the geographical position of the item.
	 * @param title
	 *            the title of the item.
	 * @param snippet
	 *            the short description of the item.
	 */
	public OverlayTextAudioItem(GeoPoint point, String title, String ttsTitle, String snippet, String ttsSnippet) 
	{
		super(point,title,snippet);
		this.ttsSnippet = (ttsSnippet != null) ? ttsSnippet : snippet;
		this.ttsTitle = (ttsTitle != null) ? ttsTitle : title;
		this.audioFile = null;
	}
	
	public String getTTSSnippet()
	{
		return ttsSnippet;
	}
	
	public String getTTSTitle()
	{
		return ttsTitle;
	}
}

